%global major 0
%global apiversion 0.8
%define libname %mklibname ixion %apiversion %major
%define devname %mklibname -d ixion

Name: libixion
Version: 0.7.0
Release: %mkrel 5
Summary: A general purpose formula parser & interpreter library

Group: System/Libraries
License: MPLv2.0
URL: https://gitorious.org/ixion/pages/Home
Source: http://kohei.us/files/ixion/src/%{name}-%{version}.tar.bz2

BuildRequires: boost-devel
BuildRequires: help2man
BuildRequires: pkgconfig(mdds)

%description
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

The goal of this project is to create a library for calculating the results of
formula expressions stored in multiple named targets, or “cells”. The cells can
be referenced from each other, and the library takes care of resolving their
dependencies automatically upon calculation. The caller can run the calculation
routine either in a single-threaded mode, or a multi-threaded mode. The library
also supports re-calculations where the contents of one or more cells have been
modified since the last calculation, and a partial calculation of only the
affected cells need to be calculated.

Supported features:
- Each calculation session is defined in a plain text file, which is parsed and
  interpreted by the Ixion parser.
- Fully threaded calculation.
- Name resolution using A1-style references.
- Support 2D cell references and named expressions.
- Support range references.
- Dependency tracking during both full calculation and partial re-calculation.
- Inline strings.
- Volatile functions. The framework for volatile functions is implemented. We
  just need to implement more functions.

%package -n %libname
Summary: A general purpose formula parser & interpreter library
Group: System/Libraries
Obsoletes: %{_lib}ixion0 < 0.7.0-3

%description -n %libname
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

The goal of this project is to create a library for calculating the results of
formula expressions stored in multiple named targets, or “cells”. The cells can
be referenced from each other, and the library takes care of resolving their
dependencies automatically upon calculation. The caller can run the calculation
routine either in a single-threaded mode, or a multi-threaded mode. The library
also supports re-calculations where the contents of one or more cells have been
modified since the last calculation, and a partial calculation of only the
affected cells need to be calculated.

Supported features:
- Each calculation session is defined in a plain text file, which is parsed and
  interpreted by the Ixion parser.
- Fully threaded calculation.
- Name resolution using A1-style references.
- Support 2D cell references and named expressions.
- Support range references.
- Dependency tracking during both full calculation and partial re-calculation.
- Inline strings.
- Volatile functions. The framework for volatile functions is implemented. We
  just need to implement more functions.


%package -n %devname
Group: Development/C
Summary: Development files for %{name}
Group: Development/C
Requires: %{libname} = %{version}-%{release}

%description -n %devname
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package tools
Summary: Tools to transform AbiWord files into other formats
Group: Office/Utilities
Requires: %{libname} = %{version}-%{release}

%description tools
Tools to transform AbiWord files into other formats. Currently
supported: XHTML, raw, text.

%prep
%setup -q

%build
%configure2_5x --disable-silent-rules --disable-static --disable-werror
sed -i \
    -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    libtool
%make

export LD_LIBRARY_PATH=`pwd`/src/libixion/.libs${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
help2man -N -n 'parser' -o ixion-parser.1 ./src/ixion-parser
help2man -N -n 'sorter' -o ixion-sorter.1 ./src/ixion-sorter

%install
%makeinstall_std
rm -f %{buildroot}/%{_libdir}/*.la

install -m 0755 -d %{buildroot}/%{_mandir}/man1
install -m 0644 ixion-parser.1 ixion-sorter.1 %{buildroot}/%{_mandir}/man1


%check
export LD_LIBRARY_PATH=`pwd`/src/libixion/.libs${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
%make check

%files -n %libname
%doc AUTHORS COPYING README
%{_libdir}/%{name}-%{apiversion}.so.%{major}
%{_libdir}/%{name}-%{apiversion}.so.%{major}.*

%files -n %devname
%doc ChangeLog
%{_includedir}/%{name}-%{apiversion}
%{_libdir}/%{name}-%{apiversion}.so
%{_libdir}/pkgconfig/%{name}-%{apiversion}.pc

%files tools
%{_bindir}/ixion-parser
%{_bindir}/ixion-sorter
%{_mandir}/man1/ixion-parser.1*
%{_mandir}/man1/ixion-sorter.1*



%changelog
* Wed Oct 15 2014 umeabot <umeabot> 0.7.0-5.mga5
+ Revision: 748054
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.0-4.mga5
+ Revision: 681544
- Mageia 5 Mass Rebuild

* Fri Aug 08 2014 wally <wally> 0.7.0-3.mga5
+ Revision: 661131
- fix lib pkg name and summary

* Thu Jul 31 2014 tv <tv> 0.7.0-2.mga5
+ Revision: 658682
- fix package names
- rebuild for having a fixed package

* Thu Jul 31 2014 tv <tv> 0.7.0-1.mga5
+ Revision: 658603
- imported package libixion

